from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Rx:
	"""Rx commands group definition. 3 total commands, 1 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rx", core, parent)

	@property
	def amPoints(self):
		"""amPoints commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_amPoints'):
			from .Rx_.AmPoints import AmPoints
			self._amPoints = AmPoints(self._core, self._base)
		return self._amPoints

	def get_se_time(self) -> float:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:RX:SETime \n
		Snippet: value: float = driver.configure.afRf.measurement.searchRoutines.rx.get_se_time() \n
		No command help available \n
			:return: setting_time: No help available
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:SROutines:RX:SETime?')
		return Conversions.str_to_float(response)

	def set_se_time(self, setting_time: float) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:RX:SETime \n
		Snippet: driver.configure.afRf.measurement.searchRoutines.rx.set_se_time(setting_time = 1.0) \n
		No command help available \n
			:param setting_time: No help available
		"""
		param = Conversions.decimal_value_to_str(setting_time)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:SROutines:RX:SETime {param}')

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.SearchRoutine:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:RX:MODE \n
		Snippet: value: enums.SearchRoutine = driver.configure.afRf.measurement.searchRoutines.rx.get_mode() \n
		No command help available \n
			:return: search_routine: No help available
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:SROutines:RX:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.SearchRoutine)

	def set_mode(self, search_routine: enums.SearchRoutine) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:RX:MODE \n
		Snippet: driver.configure.afRf.measurement.searchRoutines.rx.set_mode(search_routine = enums.SearchRoutine.RIFBandwidth) \n
		No command help available \n
			:param search_routine: No help available
		"""
		param = Conversions.enum_scalar_to_str(search_routine, enums.SearchRoutine)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:SROutines:RX:MODE {param}')

	def clone(self) -> 'Rx':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Rx(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PtFive:
	"""PtFive commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("ptFive", core, parent)

	def get_symbol_rate(self) -> int:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:PTFive:SRATe \n
		Snippet: value: int = driver.configure.vse.measurement.ptFive.get_symbol_rate() \n
		No command help available \n
			:return: symbol_rate: No help available
		"""
		response = self._core.io.query_str('CONFigure:VSE:MEASurement<Instance>:PTFive:SRATe?')
		return Conversions.str_to_int(response)

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.P25Mode:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:PTFive:MODE \n
		Snippet: value: enums.P25Mode = driver.configure.vse.measurement.ptFive.get_mode() \n
		No command help available \n
			:return: mode: No help available
		"""
		response = self._core.io.query_str('CONFigure:VSE:MEASurement<Instance>:PTFive:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.P25Mode)

	# noinspection PyTypeChecker
	def get_filter_py(self) -> enums.PulseShapingUserFilter:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:PTFive:FILTer \n
		Snippet: value: enums.PulseShapingUserFilter = driver.configure.vse.measurement.ptFive.get_filter_py() \n
		No command help available \n
			:return: filter_py: No help available
		"""
		response = self._core.io.query_str('CONFigure:VSE:MEASurement<Instance>:PTFive:FILTer?')
		return Conversions.str_to_scalar_enum(response, enums.PulseShapingUserFilter)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Result:
	"""Result commands group definition. 4 total commands, 0 Sub-groups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("result", core, parent)

	def get_ediagram(self) -> bool:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:RESult:EDIagram \n
		Snippet: value: bool = driver.configure.vse.measurement.result.get_ediagram() \n
		Enables or disables the measurement of the eye diagram. \n
			:return: eye_diagram_enable: OFF | ON
		"""
		response = self._core.io.query_str('CONFigure:VSE:MEASurement<Instance>:RESult:EDIagram?')
		return Conversions.str_to_bool(response)

	def set_ediagram(self, eye_diagram_enable: bool) -> None:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:RESult:EDIagram \n
		Snippet: driver.configure.vse.measurement.result.set_ediagram(eye_diagram_enable = False) \n
		Enables or disables the measurement of the eye diagram. \n
			:param eye_diagram_enable: OFF | ON
		"""
		param = Conversions.bool_to_str(eye_diagram_enable)
		self._core.io.write(f'CONFigure:VSE:MEASurement<Instance>:RESult:EDIagram {param}')

	def get_power_vs_time(self) -> bool:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:RESult:PVTime \n
		Snippet: value: bool = driver.configure.vse.measurement.result.get_power_vs_time() \n
		Enables or disables the measurement of the power vs. time results. \n
			:return: power_vs_time_enable: OFF | ON
		"""
		response = self._core.io.query_str('CONFigure:VSE:MEASurement<Instance>:RESult:PVTime?')
		return Conversions.str_to_bool(response)

	def set_power_vs_time(self, power_vs_time_enable: bool) -> None:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:RESult:PVTime \n
		Snippet: driver.configure.vse.measurement.result.set_power_vs_time(power_vs_time_enable = False) \n
		Enables or disables the measurement of the power vs. time results. \n
			:param power_vs_time_enable: OFF | ON
		"""
		param = Conversions.bool_to_str(power_vs_time_enable)
		self._core.io.write(f'CONFigure:VSE:MEASurement<Instance>:RESult:PVTime {param}')

	def get_cons(self) -> bool:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:RESult:CONS \n
		Snippet: value: bool = driver.configure.vse.measurement.result.get_cons() \n
		Enables or disables the measurement of the constellation diagram. \n
			:return: constellation_enable: OFF | ON
		"""
		response = self._core.io.query_str('CONFigure:VSE:MEASurement<Instance>:RESult:CONS?')
		return Conversions.str_to_bool(response)

	def set_cons(self, constellation_enable: bool) -> None:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:RESult:CONS \n
		Snippet: driver.configure.vse.measurement.result.set_cons(constellation_enable = False) \n
		Enables or disables the measurement of the constellation diagram. \n
			:param constellation_enable: OFF | ON
		"""
		param = Conversions.bool_to_str(constellation_enable)
		self._core.io.write(f'CONFigure:VSE:MEASurement<Instance>:RESult:CONS {param}')

	def get_sdis(self) -> bool:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:RESult:SDIS \n
		Snippet: value: bool = driver.configure.vse.measurement.result.get_sdis() \n
		Enables or disables the measurement of the symbol distribution results. \n
			:return: sdistribution_enable: No help available
		"""
		response = self._core.io.query_str('CONFigure:VSE:MEASurement<Instance>:RESult:SDIS?')
		return Conversions.str_to_bool(response)

	def set_sdis(self, sdistribution_enable: bool) -> None:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:RESult:SDIS \n
		Snippet: driver.configure.vse.measurement.result.set_sdis(sdistribution_enable = False) \n
		Enables or disables the measurement of the symbol distribution results. \n
			:param sdistribution_enable: OFF | ON
		"""
		param = Conversions.bool_to_str(sdistribution_enable)
		self._core.io.write(f'CONFigure:VSE:MEASurement<Instance>:RESult:SDIS {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Frequency:
	"""Frequency commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("frequency", core, parent)

	def get_atm_frequency(self) -> bool:
		"""SCPI: CONFigure:AFRF:GENerator<Instance>:VOIP:FREQuency:ATMFrequency \n
		Snippet: value: bool = driver.configure.afRf.generator.voip.frequency.get_atm_frequency() \n
		Copies the carrier center frequency to the RF measurements. The carrier frequency is indirectly configured via the FID. \n
			:return: atm_frequency: OFF | ON OFF: do not copy the frequency ON: copy the frequency when setting ON and when changing the FID in the generator
		"""
		response = self._core.io.query_str('CONFigure:AFRF:GENerator<Instance>:VOIP:FREQuency:ATMFrequency?')
		return Conversions.str_to_bool(response)

	def set_atm_frequency(self, atm_frequency: bool) -> None:
		"""SCPI: CONFigure:AFRF:GENerator<Instance>:VOIP:FREQuency:ATMFrequency \n
		Snippet: driver.configure.afRf.generator.voip.frequency.set_atm_frequency(atm_frequency = False) \n
		Copies the carrier center frequency to the RF measurements. The carrier frequency is indirectly configured via the FID. \n
			:param atm_frequency: OFF | ON OFF: do not copy the frequency ON: copy the frequency when setting ON and when changing the FID in the generator
		"""
		param = Conversions.bool_to_str(atm_frequency)
		self._core.io.write(f'CONFigure:AFRF:GENerator<Instance>:VOIP:FREQuency:ATMFrequency {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class State:
	"""State commands group definition. 2 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("state", core, parent)

	@property
	def all(self):
		"""all commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_all'):
			from .State_.All import All
			self._all = All(self._core, self._base)
		return self._all

	# noinspection PyTypeChecker
	def fetch(self) -> enums.ResourceState:
		"""SCPI: FETCh:GPRF:MEASurement<Instance>:SPECtrum:STATe \n
		Snippet: value: enums.ResourceState = driver.gprfMeasurement.spectrum.state.fetch() \n
		Queries the main spectrum analyzer state. \n
			:return: meas_state: OFF | RDY | RUN OFF Measurement is off RDY Measurement has been paused or is finished RUN Measurement is running"""
		response = self._core.io.query_str(f'FETCh:GPRF:MEASurement<Instance>:SPECtrum:STATe?')
		return Conversions.str_to_scalar_enum(response, enums.ResourceState)

	def clone(self) -> 'State':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = State(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Tetra:
	"""Tetra commands group definition. 4 total commands, 2 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("tetra", core, parent)

	@property
	def evm(self):
		"""evm commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_evm'):
			from .Tetra_.Evm import Evm
			self._evm = Evm(self._core, self._base)
		return self._evm

	@property
	def merror(self):
		"""merror commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_merror'):
			from .Tetra_.Merror import Merror
			self._merror = Merror(self._core, self._base)
		return self._merror

	def clone(self) -> 'Tetra':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Tetra(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Base:
	"""Base commands group definition. 11 total commands, 4 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("base", core, parent)

	@property
	def power(self):
		"""power commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_power'):
			from .Base_.Power import Power
			self._power = Power(self._core, self._base)
		return self._power

	@property
	def battery(self):
		"""battery commands group. 1 Sub-classes, 4 commands."""
		if not hasattr(self, '_battery'):
			from .Base_.Battery import Battery
			self._battery = Battery(self._core, self._base)
		return self._battery

	@property
	def temperature(self):
		"""temperature commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_temperature'):
			from .Base_.Temperature import Temperature
			self._temperature = Temperature(self._core, self._base)
		return self._temperature

	@property
	def reference(self):
		"""reference commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_reference'):
			from .Base_.Reference import Reference
			self._reference = Reference(self._core, self._base)
		return self._reference

	def clone(self) -> 'Base':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Base(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SysSound:
	"""SysSound commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("sysSound", core, parent)

	def get_volume(self) -> int or bool:
		"""SCPI: CONFigure:BASE:SYSSound:VOLume \n
		Snippet: value: int or bool = driver.configure.base.sysSound.get_volume() \n
		Configures the volume of the system sound. \n
			:return: ssound: OFF Switches off the system sound without changing the volume setting ON Switches on the system sound without changing the volume setting number A number greater than zero sets the volume and switches on the system sound. Zero sets the volume and switches off the system sound. Range: 0 % to 100 %, Unit: %
		"""
		response = self._core.io.query_str('CONFigure:BASE:SYSSound:VOLume?')
		return Conversions.str_to_int_or_bool(response)

	def set_volume(self, ssound: int or bool) -> None:
		"""SCPI: CONFigure:BASE:SYSSound:VOLume \n
		Snippet: driver.configure.base.sysSound.set_volume(ssound = 1) \n
		Configures the volume of the system sound. \n
			:param ssound: OFF Switches off the system sound without changing the volume setting ON Switches on the system sound without changing the volume setting number A number greater than zero sets the volume and switches on the system sound. Zero sets the volume and switches off the system sound. Range: 0 % to 100 %, Unit: %
		"""
		param = Conversions.decimal_or_bool_value_to_str(ssound)
		self._core.io.write(f'CONFigure:BASE:SYSSound:VOLume {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Oscilloscope:
	"""Oscilloscope commands group definition. 8 total commands, 4 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("oscilloscope", core, parent)

	@property
	def demodulation(self):
		"""demodulation commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_demodulation'):
			from .Oscilloscope_.Demodulation import Demodulation
			self._demodulation = Demodulation(self._core, self._base)
		return self._demodulation

	@property
	def audioInput(self):
		"""audioInput commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_audioInput'):
			from .Oscilloscope_.AudioInput import AudioInput
			self._audioInput = AudioInput(self._core, self._base)
		return self._audioInput

	@property
	def spdif(self):
		"""spdif commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_spdif'):
			from .Oscilloscope_.Spdif import Spdif
			self._spdif = Spdif(self._core, self._base)
		return self._spdif

	@property
	def voip(self):
		"""voip commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_voip'):
			from .Oscilloscope_.Voip import Voip
			self._voip = Voip(self._core, self._base)
		return self._voip

	def clone(self) -> 'Oscilloscope':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Oscilloscope(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response
from ....Internal.StructBase import StructBase
from ....Internal.ArgStruct import ArgStruct
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IqRecorder:
	"""IqRecorder commands group definition. 12 total commands, 1 Sub-groups, 9 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("iqRecorder", core, parent)

	@property
	def filterPy(self):
		"""filterPy commands group. 2 Sub-classes, 1 commands."""
		if not hasattr(self, '_filterPy'):
			from .IqRecorder_.FilterPy import FilterPy
			self._filterPy = FilterPy(self._core, self._base)
		return self._filterPy

	def get_toffset(self) -> int:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:IQRecorder:TOFFset \n
		Snippet: value: int = driver.configure.gprfMeasurement.iqRecorder.get_toffset() \n
		No command help available \n
			:return: trigger_offset: No help available
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:IQRecorder:TOFFset?')
		return Conversions.str_to_int(response)

	def set_toffset(self, trigger_offset: int) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:IQRecorder:TOFFset \n
		Snippet: driver.configure.gprfMeasurement.iqRecorder.set_toffset(trigger_offset = 1) \n
		No command help available \n
			:param trigger_offset: No help available
		"""
		param = Conversions.decimal_value_to_str(trigger_offset)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:IQRecorder:TOFFset {param}')

	def get_samples(self) -> int:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:IQRecorder:SAMPles \n
		Snippet: value: int = driver.configure.gprfMeasurement.iqRecorder.get_samples() \n
		No command help available \n
			:return: samples: No help available
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:IQRecorder:SAMPles?')
		return Conversions.str_to_int(response)

	def set_samples(self, samples: int) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:IQRecorder:SAMPles \n
		Snippet: driver.configure.gprfMeasurement.iqRecorder.set_samples(samples = 1) \n
		No command help available \n
			:param samples: No help available
		"""
		param = Conversions.decimal_value_to_str(samples)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:IQRecorder:SAMPles {param}')

	def get_timeout(self) -> float:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:IQRecorder:TOUT \n
		Snippet: value: float = driver.configure.gprfMeasurement.iqRecorder.get_timeout() \n
		Defines a timeout for the measurement. The timer is started when the measurement is initiated via a READ or INIT command.
		It is not started if the measurement is initiated via the graphical user interface. The timer is reset after the first
		measurement cycle. If the first measurement cycle has not been completed when the timer expires, the measurement is
		stopped and the reliability indicator is set to 1. Still running READ, FETCh or CALCulate commands are completed,
		returning the available results. At least for some results, there are no values at all or the statistical depth has not
		been reached. A timeout of 0 s corresponds to an infinite measurement timeout. \n
			:return: tcd_timeout: Unit: s
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:IQRecorder:TOUT?')
		return Conversions.str_to_float(response)

	def set_timeout(self, tcd_timeout: float) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:IQRecorder:TOUT \n
		Snippet: driver.configure.gprfMeasurement.iqRecorder.set_timeout(tcd_timeout = 1.0) \n
		Defines a timeout for the measurement. The timer is started when the measurement is initiated via a READ or INIT command.
		It is not started if the measurement is initiated via the graphical user interface. The timer is reset after the first
		measurement cycle. If the first measurement cycle has not been completed when the timer expires, the measurement is
		stopped and the reliability indicator is set to 1. Still running READ, FETCh or CALCulate commands are completed,
		returning the available results. At least for some results, there are no values at all or the statistical depth has not
		been reached. A timeout of 0 s corresponds to an infinite measurement timeout. \n
			:param tcd_timeout: Unit: s
		"""
		param = Conversions.decimal_value_to_str(tcd_timeout)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:IQRecorder:TOUT {param}')

	def get_ratio(self) -> float:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:IQRecorder:RATio \n
		Snippet: value: float = driver.configure.gprfMeasurement.iqRecorder.get_ratio() \n
		Defines the sample ratio and thus the sample rate (<sample rate> = <sample ratio> * <max sample rate>) . \n
			:return: ratio: Range: 0.1 to 1
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:IQRecorder:RATio?')
		return Conversions.str_to_float(response)

	def set_ratio(self, ratio: float) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:IQRecorder:RATio \n
		Snippet: driver.configure.gprfMeasurement.iqRecorder.set_ratio(ratio = 1.0) \n
		Defines the sample ratio and thus the sample rate (<sample rate> = <sample ratio> * <max sample rate>) . \n
			:param ratio: Range: 0.1 to 1
		"""
		param = Conversions.decimal_value_to_str(ratio)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:IQRecorder:RATio {param}')

	# noinspection PyTypeChecker
	def get_format_py(self) -> enums.IqFormat:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:IQRecorder:FORMat \n
		Snippet: value: enums.IqFormat = driver.configure.gprfMeasurement.iqRecorder.get_format_py() \n
		Selects a coordinate system for representation of the measurement results. \n
			:return: format_py: IQ | RPHI IQ Cartesian coordinates (I- and Q-axis) RPHI Polar coordinates (radius and angle)
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:IQRecorder:FORMat?')
		return Conversions.str_to_scalar_enum(response, enums.IqFormat)

	def set_format_py(self, format_py: enums.IqFormat) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:IQRecorder:FORMat \n
		Snippet: driver.configure.gprfMeasurement.iqRecorder.set_format_py(format_py = enums.IqFormat.IQ) \n
		Selects a coordinate system for representation of the measurement results. \n
			:param format_py: IQ | RPHI IQ Cartesian coordinates (I- and Q-axis) RPHI Polar coordinates (radius and angle)
		"""
		param = Conversions.enum_scalar_to_str(format_py, enums.IqFormat)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:IQRecorder:FORMat {param}')

	# noinspection PyTypeChecker
	def get_munit(self) -> enums.MagnitudeUnit:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:IQRecorder:MUNit \n
		Snippet: value: enums.MagnitudeUnit = driver.configure.gprfMeasurement.iqRecorder.get_munit() \n
		Selects a physical unit for representation of the measured I/Q amplitudes. \n
			:return: magnitude_unit: VOLT | RAW Voltage or raw I/Q data relative to full scale
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:IQRecorder:MUNit?')
		return Conversions.str_to_scalar_enum(response, enums.MagnitudeUnit)

	def set_munit(self, magnitude_unit: enums.MagnitudeUnit) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:IQRecorder:MUNit \n
		Snippet: driver.configure.gprfMeasurement.iqRecorder.set_munit(magnitude_unit = enums.MagnitudeUnit.RAW) \n
		Selects a physical unit for representation of the measured I/Q amplitudes. \n
			:param magnitude_unit: VOLT | RAW Voltage or raw I/Q data relative to full scale
		"""
		param = Conversions.enum_scalar_to_str(magnitude_unit, enums.MagnitudeUnit)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:IQRecorder:MUNit {param}')

	def get_iq_file(self) -> str:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:IQRecorder:IQFile \n
		Snippet: value: str = driver.configure.gprfMeasurement.iqRecorder.get_iq_file() \n
		Selects the name and path of the result file. The results are stored in the file in binary format. To write the file,
		start the measurement via INITiate:GPRF:MEAS:IQRecorder ON. \n
			:return: iq_save_file: String parameter to specify the file name and path The supported file name extensions are .iqw and .wv. The extension selects the file type.
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:IQRecorder:IQFile?')
		return trim_str_response(response)

	def set_iq_file(self, iq_save_file: str) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:IQRecorder:IQFile \n
		Snippet: driver.configure.gprfMeasurement.iqRecorder.set_iq_file(iq_save_file = '1') \n
		Selects the name and path of the result file. The results are stored in the file in binary format. To write the file,
		start the measurement via INITiate:GPRF:MEAS:IQRecorder ON. \n
			:param iq_save_file: String parameter to specify the file name and path The supported file name extensions are .iqw and .wv. The extension selects the file type.
		"""
		param = Conversions.value_to_quoted_str(iq_save_file)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:IQRecorder:IQFile {param}')

	# noinspection PyTypeChecker
	def get_wt_file(self) -> enums.FileSave:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:IQRecorder:WTFile \n
		Snippet: value: enums.FileSave = driver.configure.gprfMeasurement.iqRecorder.get_wt_file() \n
		Selects whether the results are written to an I/Q file, to the memory or both. For file selection, see method RsCma.
		Configure.GprfMeasurement.IqRecorder.iqFile. \n
			:return: save_to_iq_file: OFF | ON | ONLY OFF The results are only stored in the memory. They can be queried via remote control commands. ON The results are stored in the memory and in a file. ONLY The results are only stored in a file. Use this selection if you want to record huge amounts of data that do not fit into the memory.
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:IQRecorder:WTFile?')
		return Conversions.str_to_scalar_enum(response, enums.FileSave)

	def set_wt_file(self, save_to_iq_file: enums.FileSave) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:IQRecorder:WTFile \n
		Snippet: driver.configure.gprfMeasurement.iqRecorder.set_wt_file(save_to_iq_file = enums.FileSave.OFF) \n
		Selects whether the results are written to an I/Q file, to the memory or both. For file selection, see method RsCma.
		Configure.GprfMeasurement.IqRecorder.iqFile. \n
			:param save_to_iq_file: OFF | ON | ONLY OFF The results are only stored in the memory. They can be queried via remote control commands. ON The results are stored in the memory and in a file. ONLY The results are only stored in a file. Use this selection if you want to record huge amounts of data that do not fit into the memory.
		"""
		param = Conversions.enum_scalar_to_str(save_to_iq_file, enums.FileSave)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:IQRecorder:WTFile {param}')

	# noinspection PyTypeChecker
	class CaptureStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Capt_Samp_Bef_Trig: int: Samples before the trigger event Range: 1 to 67108863
			- Capt_Samp_Aft_Trig: int: Samples after the trigger event Range: 1 to 67108863"""
		__meta_args_list = [
			ArgStruct.scalar_int('Capt_Samp_Bef_Trig'),
			ArgStruct.scalar_int('Capt_Samp_Aft_Trig')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Capt_Samp_Bef_Trig: int = None
			self.Capt_Samp_Aft_Trig: int = None

	def get_capture(self) -> CaptureStruct:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:IQRecorder:CAPTure \n
		Snippet: value: CaptureStruct = driver.configure.gprfMeasurement.iqRecorder.get_capture() \n
		Defines the number of samples to be evaluated before the trigger event and after the trigger event. The maximum total
		number of samples is 67108864. The sum of the two settings must not exceed this value. \n
			:return: structure: for return value, see the help for CaptureStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:GPRF:MEASurement<Instance>:IQRecorder:CAPTure?', self.__class__.CaptureStruct())

	def set_capture(self, value: CaptureStruct) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:IQRecorder:CAPTure \n
		Snippet: driver.configure.gprfMeasurement.iqRecorder.set_capture(value = CaptureStruct()) \n
		Defines the number of samples to be evaluated before the trigger event and after the trigger event. The maximum total
		number of samples is 67108864. The sum of the two settings must not exceed this value. \n
			:param value: see the help for CaptureStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:GPRF:MEASurement<Instance>:IQRecorder:CAPTure', value)

	def clone(self) -> 'IqRecorder':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = IqRecorder(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModDepth:
	"""ModDepth commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("modDepth", core, parent)

	def get_threshold(self) -> float:
		"""SCPI: TRIGger:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:DEModulation:MDEPth:THReshold \n
		Snippet: value: float = driver.trigger.afRf.measurement.multiEval.oscilloscope.demodulation.modDepth.get_threshold() \n
		Defines the trigger threshold for the RF input path, for AM demodulation. \n
			:return: threshold: Modulation depth threshold Range: -100 % to 100 %, Unit: %
		"""
		response = self._core.io.query_str('TRIGger:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:DEModulation:MDEPth:THReshold?')
		return Conversions.str_to_float(response)

	def set_threshold(self, threshold: float) -> None:
		"""SCPI: TRIGger:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:DEModulation:MDEPth:THReshold \n
		Snippet: driver.trigger.afRf.measurement.multiEval.oscilloscope.demodulation.modDepth.set_threshold(threshold = 1.0) \n
		Defines the trigger threshold for the RF input path, for AM demodulation. \n
			:param threshold: Modulation depth threshold Range: -100 % to 100 %, Unit: %
		"""
		param = Conversions.decimal_value_to_str(threshold)
		self._core.io.write(f'TRIGger:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:DEModulation:MDEPth:THReshold {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.StructBase import StructBase
from .....Internal.ArgStruct import ArgStruct
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Rsensitivity:
	"""Rsensitivity commands group definition. 10 total commands, 3 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rsensitivity", core, parent)

	@property
	def rfLevel(self):
		"""rfLevel commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_rfLevel'):
			from .Rsensitivity_.RfLevel import RfLevel
			self._rfLevel = RfLevel(self._core, self._base)
		return self._rfLevel

	@property
	def signalQuality(self):
		"""signalQuality commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_signalQuality'):
			from .Rsensitivity_.SignalQuality import SignalQuality
			self._signalQuality = SignalQuality(self._core, self._base)
		return self._signalQuality

	@property
	def sensitivity(self):
		"""sensitivity commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_sensitivity'):
			from .Rsensitivity_.Sensitivity import Sensitivity
			self._sensitivity = Sensitivity(self._core, self._base)
		return self._sensitivity

	# noinspection PyTypeChecker
	class ResultData(StructBase):
		"""Response structure. Fields: \n
			- Reliability: int: See 'Reliability indicator values'
			- Sensitivity_Level: float: Measured RX sensitivity level (RF level) Unit: dBm
			- Signal_Quality: float: Audio signal quality value measured at the RX sensitivity level Unit: dB"""
		__meta_args_list = [
			ArgStruct.scalar_int('Reliability', 'Reliability'),
			ArgStruct.scalar_float('Sensitivity_Level'),
			ArgStruct.scalar_float('Signal_Quality')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Reliability: int = None
			self.Sensitivity_Level: float = None
			self.Signal_Quality: float = None

	def fetch(self) -> ResultData:
		"""SCPI: FETCh:AFRF:MEASurement<Instance>:SROutines:RSENsitivity \n
		Snippet: value: ResultData = driver.afRf.measurement.searchRoutines.rsensitivity.fetch() \n
		Returns the single results of the RX sensitivity search routine. CALCulate commands return error indicators instead of
		measurement values. \n
			:return: structure: for return value, see the help for ResultData structure arguments."""
		return self._core.io.query_struct(f'FETCh:AFRF:MEASurement<Instance>:SROutines:RSENsitivity?', self.__class__.ResultData())

	# noinspection PyTypeChecker
	class CalculateStruct(StructBase):
		"""Response structure. Fields: \n
			- Reliability: int: See 'Reliability indicator values'
			- Sensitivity_Level: enums.ResultStatus: Measured RX sensitivity level (RF level) Unit: dBm
			- Signal_Quality: enums.ResultStatus: Audio signal quality value measured at the RX sensitivity level Unit: dB"""
		__meta_args_list = [
			ArgStruct.scalar_int('Reliability', 'Reliability'),
			ArgStruct.scalar_enum('Sensitivity_Level', enums.ResultStatus),
			ArgStruct.scalar_enum('Signal_Quality', enums.ResultStatus)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Reliability: int = None
			self.Sensitivity_Level: enums.ResultStatus = None
			self.Signal_Quality: enums.ResultStatus = None

	def calculate(self) -> CalculateStruct:
		"""SCPI: CALCulate:AFRF:MEASurement<Instance>:SROutines:RSENsitivity \n
		Snippet: value: CalculateStruct = driver.afRf.measurement.searchRoutines.rsensitivity.calculate() \n
		Returns the single results of the RX sensitivity search routine. CALCulate commands return error indicators instead of
		measurement values. \n
			:return: structure: for return value, see the help for CalculateStruct structure arguments."""
		return self._core.io.query_struct(f'CALCulate:AFRF:MEASurement<Instance>:SROutines:RSENsitivity?', self.__class__.CalculateStruct())

	def read(self) -> ResultData:
		"""SCPI: READ:AFRF:MEASurement<Instance>:SROutines:RSENsitivity \n
		Snippet: value: ResultData = driver.afRf.measurement.searchRoutines.rsensitivity.read() \n
		No command help available \n
			:return: structure: for return value, see the help for ResultData structure arguments."""
		return self._core.io.query_struct(f'READ:AFRF:MEASurement<Instance>:SROutines:RSENsitivity?', self.__class__.ResultData())

	def clone(self) -> 'Rsensitivity':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Rsensitivity(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AfSettings:
	"""AfSettings commands group definition. 13 total commands, 3 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("afSettings", core, parent)

	@property
	def audioOutput(self):
		"""audioOutput commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_audioOutput'):
			from .AfSettings_.AudioOutput import AudioOutput
			self._audioOutput = AudioOutput(self._core, self._base)
		return self._audioOutput

	@property
	def reference(self):
		"""reference commands group. 1 Sub-classes, 4 commands."""
		if not hasattr(self, '_reference'):
			from .AfSettings_.Reference import Reference
			self._reference = Reference(self._core, self._base)
		return self._reference

	@property
	def vphase(self):
		"""vphase commands group. 0 Sub-classes, 4 commands."""
		if not hasattr(self, '_vphase'):
			from .AfSettings_.Vphase import Vphase
			self._vphase = Vphase(self._core, self._base)
		return self._vphase

	# noinspection PyTypeChecker
	def get_connector(self) -> enums.AudioConnector:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:CONNector \n
		Snippet: value: enums.AudioConnector = driver.source.avionics.generator.vor.afSettings.get_connector() \n
		Selects the output connector for the generated AF signal (AF1 OUT or AF2 OUT) . \n
			:return: connector: AF1O | AF2O
		"""
		response = self._core.io.query_str('SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:CONNector?')
		return Conversions.str_to_scalar_enum(response, enums.AudioConnector)

	def set_connector(self, connector: enums.AudioConnector) -> None:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:CONNector \n
		Snippet: driver.source.avionics.generator.vor.afSettings.set_connector(connector = enums.AudioConnector.AF1O) \n
		Selects the output connector for the generated AF signal (AF1 OUT or AF2 OUT) . \n
			:param connector: AF1O | AF2O
		"""
		param = Conversions.enum_scalar_to_str(connector, enums.AudioConnector)
		self._core.io.write(f'SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:CONNector {param}')

	def clone(self) -> 'AfSettings':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = AfSettings(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.StructBase import StructBase
from .....Internal.ArgStruct import ArgStruct
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Sout:
	"""Sout commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("sout", core, parent)

	# noinspection PyTypeChecker
	class EnableStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable_Left: bool: OFF | ON Switches the left channel off or on
			- Enable_Right: bool: OFF | ON Switches the right channel off or on"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable_Left'),
			ArgStruct.scalar_bool('Enable_Right')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable_Left: bool = None
			self.Enable_Right: bool = None

	def get_enable(self) -> EnableStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SOUT:ENABle \n
		Snippet: value: EnableStruct = driver.configure.afRf.measurement.sout.get_enable() \n
		Enables or disables the channels of the SPDIF OUT connector. \n
			:return: structure: for return value, see the help for EnableStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:SOUT:ENABle?', self.__class__.EnableStruct())

	def set_enable(self, value: EnableStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SOUT:ENABle \n
		Snippet: driver.configure.afRf.measurement.sout.set_enable(value = EnableStruct()) \n
		Enables or disables the channels of the SPDIF OUT connector. \n
			:param value: see the help for EnableStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:SOUT:ENABle', value)

	# noinspection PyTypeChecker
	class SourceStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Source_Left: enums.AudioSource: DEM | DEML Source for the left SPDIF channel DEM Demodulator output (FM, PM, ...) DEML Demodulator output, left channel (FM stereo)
			- Source_Right: enums.AudioSource: DEM | DEMR Source for the right SPDIF channel DEM Demodulator output (FM, PM, ...) DEMR Demodulator output, right channel (FM stereo)"""
		__meta_args_list = [
			ArgStruct.scalar_enum('Source_Left', enums.AudioSource),
			ArgStruct.scalar_enum('Source_Right', enums.AudioSource)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Source_Left: enums.AudioSource = None
			self.Source_Right: enums.AudioSource = None

	# noinspection PyTypeChecker
	def get_source(self) -> SourceStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SOUT:SOURce \n
		Snippet: value: SourceStruct = driver.configure.afRf.measurement.sout.get_source() \n
		Queries the audio signal sources for the SPDIF OUT connector. \n
			:return: structure: for return value, see the help for SourceStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:SOUT:SOURce?', self.__class__.SourceStruct())

	# noinspection PyTypeChecker
	class LevelStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Level_Left: float: Level for the left channel Unit: %
			- Level_Right: float: Level for the right channel Unit: %"""
		__meta_args_list = [
			ArgStruct.scalar_float('Level_Left'),
			ArgStruct.scalar_float('Level_Right')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Level_Left: float = None
			self.Level_Right: float = None

	def get_level(self) -> LevelStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SOUT:LEVel \n
		Snippet: value: LevelStruct = driver.configure.afRf.measurement.sout.get_level() \n
		Specifies the output levels for the SPDIF OUT connector. \n
			:return: structure: for return value, see the help for LevelStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:SOUT:LEVel?', self.__class__.LevelStruct())

	def set_level(self, value: LevelStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SOUT:LEVel \n
		Snippet: driver.configure.afRf.measurement.sout.set_level(value = LevelStruct()) \n
		Specifies the output levels for the SPDIF OUT connector. \n
			:param value: see the help for LevelStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:SOUT:LEVel', value)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Device:
	"""Device commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("device", core, parent)

	def set(self) -> None:
		"""SCPI: SYSTem:BASE:SHUTdown:DEVice \n
		Snippet: driver.system.base.shutdown.device.set() \n
		Shuts down the instrument. \n
		"""
		self._core.io.write(f'SYSTem:BASE:SHUTdown:DEVice')

	def set_with_opc(self) -> None:
		"""SCPI: SYSTem:BASE:SHUTdown:DEVice \n
		Snippet: driver.system.base.shutdown.device.set_with_opc() \n
		Shuts down the instrument. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'SYSTem:BASE:SHUTdown:DEVice')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Dfrequency:
	"""Dfrequency commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("dfrequency", core, parent)

	def set(self, distor_freq: float, audioInput=repcap.AudioInput.Default) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:AIN<nr>:FILTer:DFRequency \n
		Snippet: driver.configure.afRf.measurement.audioInput.filterPy.dfrequency.set(distor_freq = 1.0, audioInput = repcap.AudioInput.Default) \n
		Configures the reference frequency for single-tone measurements via an AF input path. \n
			:param distor_freq: Range: 1 Hz to 10.5 kHz, Unit: Hz
			:param audioInput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioInput')"""
		param = Conversions.decimal_value_to_str(distor_freq)
		audioInput_cmd_val = self._base.get_repcap_cmd_value(audioInput, repcap.AudioInput)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:AIN{audioInput_cmd_val}:FILTer:DFRequency {param}')

	def get(self, audioInput=repcap.AudioInput.Default) -> float:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:AIN<nr>:FILTer:DFRequency \n
		Snippet: value: float = driver.configure.afRf.measurement.audioInput.filterPy.dfrequency.get(audioInput = repcap.AudioInput.Default) \n
		Configures the reference frequency for single-tone measurements via an AF input path. \n
			:param audioInput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioInput')
			:return: distor_freq: Range: 1 Hz to 10.5 kHz, Unit: Hz"""
		audioInput_cmd_val = self._base.get_repcap_cmd_value(audioInput, repcap.AudioInput)
		response = self._core.io.query_str(f'CONFigure:AFRF:MEASurement<Instance>:AIN{audioInput_cmd_val}:FILTer:DFRequency?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RfOut:
	"""RfOut commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rfOut", core, parent)

	def get_enable(self) -> bool:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:MBEacon:RFSettings:RFOut:ENABle \n
		Snippet: value: bool = driver.source.avionics.generator.markerBeacon.rfSettings.rfOut.get_enable() \n
		Enables or disables the RF output path. \n
			:return: rf_enable: OFF | ON
		"""
		response = self._core.io.query_str('SOURce:AVIonics:GENerator<Instance>:MBEacon:RFSettings:RFOut:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, rf_enable: bool) -> None:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:MBEacon:RFSettings:RFOut:ENABle \n
		Snippet: driver.source.avionics.generator.markerBeacon.rfSettings.rfOut.set_enable(rf_enable = False) \n
		Enables or disables the RF output path. \n
			:param rf_enable: OFF | ON
		"""
		param = Conversions.bool_to_str(rf_enable)
		self._core.io.write(f'SOURce:AVIonics:GENerator<Instance>:MBEacon:RFSettings:RFOut:ENABle {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Types import DataType
from ......Internal.ArgSingleList import ArgSingleList
from ......Internal.ArgSingle import ArgSingle
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Munit:
	"""Munit commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("munit", core, parent)

	def set(self, magnitude_unit: enums.MagnitudeUnit, standard: enums.Standard = None) -> None:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:IQRecorder:MUNit \n
		Snippet: driver.configure.vse.measurement.iqRecorder.munit.set(magnitude_unit = enums.MagnitudeUnit.RAW, standard = enums.Standard.CUSTom) \n
		Selects or queries the physical unit for representation of the recorded I/Q data. \n
			:param magnitude_unit: VOLT | RAW
			:param standard: DMR | NXDN | P25 | TETRa | LTE | UDEFined
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('magnitude_unit', magnitude_unit, DataType.Enum), ArgSingle('standard', standard, DataType.Enum, True))
		self._core.io.write(f'CONFigure:VSE:MEASurement<Instance>:IQRecorder:MUNit {param}'.rstrip())

	# noinspection PyTypeChecker
	def get(self) -> enums.MagnitudeUnit:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:IQRecorder:MUNit \n
		Snippet: value: enums.MagnitudeUnit = driver.configure.vse.measurement.iqRecorder.munit.get() \n
		Selects or queries the physical unit for representation of the recorded I/Q data. \n
			:return: magnitude_unit: VOLT | RAW"""
		response = self._core.io.query_str(f'CONFigure:VSE:MEASurement<Instance>:IQRecorder:MUNit?')
		return Conversions.str_to_scalar_enum(response, enums.MagnitudeUnit)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Marker:
	"""Marker commands group definition. 2 total commands, 2 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("marker", core, parent)
		
		self._base.multi_repcap_types = "MarkerOther,Marker"

	@property
	def placement(self):
		"""placement commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_placement'):
			from .Marker_.Placement import Placement
			self._placement = Placement(self._core, self._base)
		return self._placement

	@property
	def range(self):
		"""range commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_range'):
			from .Marker_.Range import Range
			self._range = Range(self._core, self._base)
		return self._range

	def clone(self) -> 'Marker':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Marker(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Catalog:
	"""Catalog commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("catalog", core, parent)

	def get_source(self) -> List[str]:
		"""SCPI: TRIGger:GPRF:MEASurement<Instance>:FFTSanalyzer:CATalog:SOURce \n
		Snippet: value: List[str] = driver.trigger.gprfMeasurement.fftSpecAn.catalog.get_source() \n
		Returns a list of all trigger source values that can be selected via method RsCma.Trigger.GprfMeasurement.FftSpecAn.
		source. \n
			:return: trigger_sources: Comma-separated list of all strings, one string per source
		"""
		response = self._core.io.query_str('TRIGger:GPRF:MEASurement<Instance>:FFTSanalyzer:CATalog:SOURce?')
		return Conversions.str_to_str_list(response)



from typing import List

from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.ArgSingleSuppressed import ArgSingleSuppressed
from ........Internal.Types import DataType


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Average:
	"""Average commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("average", core, parent)

	def fetch(self) -> List[float]:
		"""SCPI: FETCh:AFRF:MEASurement<Instance>:MEValuation:FFT:DEModulation:USBPower:AVERage \n
		Snippet: value: List[float] = driver.afRf.measurement.multiEval.fft.demodulation.usbPower.average.fetch() \n
		Queries the contents of the spectrum diagram for SSB-USB demodulation. \n
		Use RsCma.reliability.last_value to read the updated reliability indicator. \n
			:return: power: Comma-separated list of 1793 audio level values (diagram from left to right) Unit: dBFS"""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_bin_or_ascii_float_list_suppressed(f'FETCh:AFRF:MEASurement<Instance>:MEValuation:FFT:DEModulation:USBPower:AVERage?', suppressed)
		return response

	def read(self) -> List[float]:
		"""SCPI: READ:AFRF:MEASurement<Instance>:MEValuation:FFT:DEModulation:USBPower:AVERage \n
		Snippet: value: List[float] = driver.afRf.measurement.multiEval.fft.demodulation.usbPower.average.read() \n
		Queries the contents of the spectrum diagram for SSB-USB demodulation. \n
		Use RsCma.reliability.last_value to read the updated reliability indicator. \n
			:return: power: Comma-separated list of 1793 audio level values (diagram from left to right) Unit: dBFS"""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_bin_or_ascii_float_list_suppressed(f'READ:AFRF:MEASurement<Instance>:MEValuation:FFT:DEModulation:USBPower:AVERage?', suppressed)
		return response



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.StructBase import StructBase
from ....Internal.ArgStruct import ArgStruct
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FftSpecAn:
	"""FftSpecAn commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("fftSpecAn", core, parent)

	# noinspection PyTypeChecker
	class TraceStruct(StructBase):
		"""Structure for setting input parameters. Contains optional set arguments. Fields: \n
			- Trace_Enable: bool: OFF | ON Disables or enables the trace/diagrams selected via Trace
			- Trace: enums.TraceB: Optional setting parameter. CURRent | AVERage | MAXimum | MINimum | TDOMmain Selects the trace (current, average, max, min) or diagrams (time domain) to be enabled/disabled To enable or disable all traces and diagrams, omit the parameter."""
		__meta_args_list = [
			ArgStruct.scalar_bool('Trace_Enable'),
			ArgStruct.scalar_enum_optional('Trace', enums.TraceB)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Trace_Enable: bool = None
			self.Trace: enums.TraceB = None

	def set_trace(self, value: TraceStruct) -> None:
		"""SCPI: DISPlay:GPRF:MEASurement<Instance>:FFTSanalyzer:TRACe \n
		Snippet: driver.display.gprfMeasurement.fftSpecAn.set_trace(value = TraceStruct()) \n
		Selects which traces and diagrams are displayed on the 'FFT Spectrum' tab. \n
			:param value: see the help for TraceStruct structure arguments.
		"""
		self._core.io.write_struct('DISPlay:GPRF:MEASurement<Instance>:FFTSanalyzer:TRACe', value)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ReferenceMarker:
	"""ReferenceMarker commands group definition. 2 total commands, 2 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("referenceMarker", core, parent)

	@property
	def speak(self):
		"""speak commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_speak'):
			from .ReferenceMarker_.Speak import Speak
			self._speak = Speak(self._core, self._base)
		return self._speak

	@property
	def npeak(self):
		"""npeak commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_npeak'):
			from .ReferenceMarker_.Npeak import Npeak
			self._npeak = Npeak(self._core, self._base)
		return self._npeak

	def clone(self) -> 'ReferenceMarker':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ReferenceMarker(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IqRecorder:
	"""IqRecorder commands group definition. 8 total commands, 6 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("iqRecorder", core, parent)

	@property
	def lte(self):
		"""lte commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_lte'):
			from .IqRecorder_.Lte import Lte
			self._lte = Lte(self._core, self._base)
		return self._lte

	@property
	def capture(self):
		"""capture commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_capture'):
			from .IqRecorder_.Capture import Capture
			self._capture = Capture(self._core, self._base)
		return self._capture

	@property
	def ratio(self):
		"""ratio commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ratio'):
			from .IqRecorder_.Ratio import Ratio
			self._ratio = Ratio(self._core, self._base)
		return self._ratio

	@property
	def symbolRate(self):
		"""symbolRate commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_symbolRate'):
			from .IqRecorder_.SymbolRate import SymbolRate
			self._symbolRate = SymbolRate(self._core, self._base)
		return self._symbolRate

	@property
	def munit(self):
		"""munit commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_munit'):
			from .IqRecorder_.Munit import Munit
			self._munit = Munit(self._core, self._base)
		return self._munit

	@property
	def filterPy(self):
		"""filterPy commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_filterPy'):
			from .IqRecorder_.FilterPy import FilterPy
			self._filterPy = FilterPy(self._core, self._base)
		return self._filterPy

	def clone(self) -> 'IqRecorder':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = IqRecorder(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Gpib:
	"""Gpib commands group definition. 3 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("gpib", core, parent)

	@property
	def self(self):
		"""self commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_self'):
			from .Gpib_.Self import Self
			self._self = Self(self._core, self._base)
		return self._self

	def get_vresource(self) -> str:
		"""SCPI: SYSTem:COMMunicate:GPIB:VRESource \n
		Snippet: value: str = driver.system.communicate.gpib.get_vresource() \n
		Queries the VISA resource string of the GPIB interface. \n
			:return: visa_resource: VISA resource string
		"""
		response = self._core.io.query_str('SYSTem:COMMunicate:GPIB:VRESource?')
		return trim_str_response(response)

	def clone(self) -> 'Gpib':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Gpib(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.ArgSingleSuppressed import ArgSingleSuppressed
from .....Internal.Types import DataType


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Maximum:
	"""Maximum commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("maximum", core, parent)

	def fetch(self) -> List[float]:
		"""SCPI: FETCh:GPRF:MEASurement<Instance>:FFTSanalyzer:POWer:MAXimum \n
		Snippet: value: List[float] = driver.gprfMeasurement.fftSpecAn.power.maximum.fetch() \n
		Queries the contents of the spectrum diagram. There are separate commands for the current, average, minimum and maximum
		power traces. \n
		Use RsCma.reliability.last_value to read the updated reliability indicator. \n
			:return: power: Comma-separated list of 801 power values The power values cover the entire measured frequency span, from the lower end to the upper end. The frequency distance between two results equals span/800. Unit: dBm"""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_bin_or_ascii_float_list_suppressed(f'FETCh:GPRF:MEASurement<Instance>:FFTSanalyzer:POWer:MAXimum?', suppressed)
		return response

	def read(self) -> List[float]:
		"""SCPI: READ:GPRF:MEASurement<Instance>:FFTSanalyzer:POWer:MAXimum \n
		Snippet: value: List[float] = driver.gprfMeasurement.fftSpecAn.power.maximum.read() \n
		Queries the contents of the spectrum diagram. There are separate commands for the current, average, minimum and maximum
		power traces. \n
		Use RsCma.reliability.last_value to read the updated reliability indicator. \n
			:return: power: Comma-separated list of 801 power values The power values cover the entire measured frequency span, from the lower end to the upper end. The frequency distance between two results equals span/800. Unit: dBm"""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_bin_or_ascii_float_list_suppressed(f'READ:GPRF:MEASurement<Instance>:FFTSanalyzer:POWer:MAXimum?', suppressed)
		return response



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Dialing:
	"""Dialing commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("dialing", core, parent)

	# noinspection PyTypeChecker
	class TimeoutStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable: bool: No parameter help available
			- Mode: enums.TimeoutMode: No parameter help available
			- Timeout: float: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable'),
			ArgStruct.scalar_enum('Mode', enums.TimeoutMode),
			ArgStruct.scalar_float('Timeout')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable: bool = None
			self.Mode: enums.TimeoutMode = None
			self.Timeout: float = None

	def get_timeout(self) -> TimeoutStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:DIALing:TOUT \n
		Snippet: value: TimeoutStruct = driver.configure.afRf.measurement.multiEval.tones.dialing.get_timeout() \n
		No command help available \n
			:return: structure: for return value, see the help for TimeoutStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:DIALing:TOUT?', self.__class__.TimeoutStruct())

	def set_timeout(self, value: TimeoutStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:DIALing:TOUT \n
		Snippet: driver.configure.afRf.measurement.multiEval.tones.dialing.set_timeout(value = TimeoutStruct()) \n
		No command help available \n
			:param value: see the help for TimeoutStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:DIALing:TOUT', value)

	# noinspection PyTypeChecker
	class ToStartStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable: bool: OFF | ON Enables the timeout
			- Timeout: float: Time interval during which the first tone must be detected Range: 0.8 s to 86400 s, Unit: s"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable'),
			ArgStruct.scalar_float('Timeout')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable: bool = None
			self.Timeout: float = None

	def get_to_start(self) -> ToStartStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:DIALing:TOSTart \n
		Snippet: value: ToStartStruct = driver.configure.afRf.measurement.multiEval.tones.dialing.get_to_start() \n
		Configures a timeout for the detection of the first tone during a dialing sequence analysis. \n
			:return: structure: for return value, see the help for ToStartStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:DIALing:TOSTart?', self.__class__.ToStartStruct())

	def set_to_start(self, value: ToStartStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:DIALing:TOSTart \n
		Snippet: driver.configure.afRf.measurement.multiEval.tones.dialing.set_to_start(value = ToStartStruct()) \n
		Configures a timeout for the detection of the first tone during a dialing sequence analysis. \n
			:param value: see the help for ToStartStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:DIALing:TOSTart', value)

	# noinspection PyTypeChecker
	class ToEndStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable: bool: OFF | ON Enables the timeout
			- Timeout: float: Maximum time interval after the end of a tone and the start of the next tone Range: 0.1 s to 30 s, Unit: s"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable'),
			ArgStruct.scalar_float('Timeout')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable: bool = None
			self.Timeout: float = None

	def get_to_end(self) -> ToEndStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:DIALing:TOENd \n
		Snippet: value: ToEndStruct = driver.configure.afRf.measurement.multiEval.tones.dialing.get_to_end() \n
		Configures a timeout for waiting for the next tone during a dialing sequence analysis. \n
			:return: structure: for return value, see the help for ToEndStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:DIALing:TOENd?', self.__class__.ToEndStruct())

	def set_to_end(self, value: ToEndStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:DIALing:TOENd \n
		Snippet: driver.configure.afRf.measurement.multiEval.tones.dialing.set_to_end(value = ToEndStruct()) \n
		Configures a timeout for waiting for the next tone during a dialing sequence analysis. \n
			:param value: see the help for ToEndStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:DIALing:TOENd', value)
